==> acl2_8.0dfsg.orig.tar.gz: acl2-8.0dfsg/books/std/strings/isort.lisp <==
; ACL2 String Library
; Copyright (C) 2009-2013 Centaur Technology
;
; Contact:
;   Centaur Technology Formal Verification Group
;   7600-C N. Capital of Texas Highway, Suite 300, Austin, TX 78731, USA.
;   http://www.centtech.com/
;
; License: (An MIT/X11-style license)
;
;   Permission is hereby granted, free of charge, to any person obtaining a
;   copy of this software and associated documentation files (the "Software"),
;   to deal in the Software without restriction, including without limitation
;   the rights to use, copy, modify, merge, publish, distribute, sublicense,
;   and/or sell copies of the Software, and to permit persons to whom the
;   Software is furnished to do so, subject to the following conditions:
;
;   The above copyright notice and this permission notice shall be included in
;   all copies or substantial portions of the Software.
;
;   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
;   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
;   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
;   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
;   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
;   FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
;   DEALINGS IN THE SOFTWARE.
;
; Original author: Jared Davis <jared@centtech.com>

(in-package "STR")
(include-book "iless")
(include-book "defsort/defsort" :dir :system)
(local (include-book "std/typed-lists/string-listp" :dir :system))

(ACL2::defsort
 :comparablep stringp
 :compare< istr<
 :prefix istr)

(defthm istr-list-p-removal
  (equal (istr-list-p x)
         (string-listp (list-fix x)))
  :hints(("Goal" :in-theory (enable istr-list-p))))

(defthm string-listp-of-istr-sort
  (implies (force (string-listp x))
           (string-listp (istr-sort x)))
  :hints(("Goal"
          :in-theory (disable istr-sort-creates-comparable-listp)
          :use ((:instance istr-sort-creates-comparable-listp)))))

(defsection istrsort
  :parents (ordering)
  :short "Case-insensitively sort a string list."
  :long "<p>This is an efficient, stable mergesort for string lists based on
@(see istr<) and implemented with the defsort book.</p>"

  (defmacro istrsort (x)
    `(istr-sort ,x)))

(add-macro-alias istrsort istr-sort)

==> acl2_8.5dfsg.orig.tar.gz: acl2-8.5dfsg/books/std/strings/isort.lisp <==
; ACL2 String Library
; Copyright (C) 2009-2013 Centaur Technology
;
; Contact:
;   Centaur Technology Formal Verification Group
;   7600-C N. Capital of Texas Highway, Suite 300, Austin, TX 78731, USA.
;   http://www.centtech.com/
;
; License: (An MIT/X11-style license)
;
;   Permission is hereby granted, free of charge, to any person obtaining a
;   copy of this software and associated documentation files (the "Software"),
;   to deal in the Software without restriction, including without limitation
;   the rights to use, copy, modify, merge, publish, distribute, sublicense,
;   and/or sell copies of the Software, and to permit persons to whom the
;   Software is furnished to do so, subject to the following conditions:
;
;   The above copyright notice and this permission notice shall be included in
;   all copies or substantial portions of the Software.
;
;   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
;   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
;   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
;   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
;   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
;   FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
;   DEALINGS IN THE SOFTWARE.
;
; Original author: Jared Davis <jared@centtech.com>

(in-package "STR")
(include-book "iless")
(include-book "defsort/defsort" :dir :system)
(local (include-book "std/typed-lists/string-listp" :dir :system))

(ACL2::defsort
 :comparablep stringp
 :compare< istr<
 :prefix istr)

(defthm istr-list-p-removal
  (equal (istr-list-p x)
         (string-listp (list-fix x)))
  :hints(("Goal" :in-theory (enable istr-list-p))))

(defthm string-listp-of-istr-sort
  (implies (force (string-listp x))
           (string-listp (istr-sort x)))
  :hints(("Goal"
          :in-theory (disable istr-sort-creates-comparable-listp)
          :use ((:instance istr-sort-creates-comparable-listp)))))

(defsection istrsort
  :parents (ordering)
  :short "Case-insensitively sort a string list."
  :long "<p>This is an efficient, stable mergesort for string lists based on
@(see istr<) and implemented with the @(see acl2::defsort) book.</p>"

  (defmacro istrsort (x)
    `(istr-sort ,x)))

(add-macro-alias istrsort istr-sort)
